"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rotating_file_stream_1 = require("rotating-file-stream");
var path_1 = require("path");
var moment = require("moment");
var qs_1 = require("qs");
var debug_helper_1 = require("./util/debug_helper");
var logError = debug_helper_1.default(__filename).logError;
var baseAxiosConfig = {
    timeout: 10000,
    headers: {
        'User-Agent': 'ts-crypto-cli',
        'content-type': 'application/x-www-form-urlencoded',
    }
};
exports.baseAxiosConfig = baseAxiosConfig;
var TS_CRYPTO_CLI_LOGS_PATH = process.env.TS_CRYPTO_CLI_LOGS_PATH;
var dirPath = TS_CRYPTO_CLI_LOGS_PATH ? path_1.resolve(TS_CRYPTO_CLI_LOGS_PATH) : null;
// Rotating filenames
var calculateFileName = function (date, index) {
    var fileName = "ts-crypto-cli_" + moment().utc().format('YYYY_MMM');
    if (!date)
        return fileName + ".csv";
    return fileName + "_" + index + ".csv";
};
var stream = dirPath ? rotating_file_stream_1.createStream(calculateFileName, {
    size: "100M",
    interval: "1M",
    path: dirPath,
    immutable: true,
}) : null;
var baseAxiosRequestInterceptor = function (config) {
    if (['PUT', 'POST', 'PATCH'].includes(config.method.toUpperCase())) {
        delete config.params;
        config.data = qs_1.stringify(config.data);
    }
    else {
        delete config.data;
    }
    var _a = config || {}, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, _c = _a.data, data = _c === void 0 ? '-' : _c;
    if (stream)
        stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + data + "; -; -; -");
    return config;
};
exports.baseAxiosRequestInterceptor = baseAxiosRequestInterceptor;
var baseAxiosResponseInterceptor = function (response) {
    var _a = response || {}, _b = _a.config, method = _b.method, baseURL = _b.baseURL, url = _b.url, _c = _b.params, params = _c === void 0 ? '-' : _c, _d = _a.status, status = _d === void 0 ? null : _d, _e = _a.statusText, statusText = _e === void 0 ? '-' : _e, _f = _a.data, data = _f === void 0 ? '-' : _f;
    if (stream)
        stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + typeof data + "; " + status + "; " + statusText + "; -");
    return response;
};
exports.baseAxiosResponseInterceptor = baseAxiosResponseInterceptor;
var baseAxiosRequestErrorInterceptor = function (axiosRequestError) {
    var _a = axiosRequestError || {}, _b = _a.config, method = _b.method, baseURL = _b.baseURL, url = _b.url, _c = _b.params, params = _c === void 0 ? '-' : _c, _d = _b.data, data = _d === void 0 ? '-' : _d, _e = _a.code, code = _e === void 0 ? '-' : _e, _f = _a.response, _g = _f === void 0 ? {} : _f, _h = _g.status, status = _h === void 0 ? null : _h, _j = _g.statusText, statusText = _j === void 0 ? '-' : _j;
    if (stream)
        stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + JSON.stringify(data) + "; " + status + "; " + statusText + "; " + code);
    logError({ axiosRequestError: axiosRequestError });
    throw axiosRequestError;
};
exports.baseAxiosRequestErrorInterceptor = baseAxiosRequestErrorInterceptor;
var baseAxiosResponseErrorInterceptor = function (axiosResponseError) {
    var _a = axiosResponseError || {}, _b = _a.config, method = _b.method, baseURL = _b.baseURL, url = _b.url, _c = _b.params, params = _c === void 0 ? '-' : _c, _d = _b.data, data = _d === void 0 ? '-' : _d, _e = _a.code, code = _e === void 0 ? '-' : _e, _f = _a.response, _g = _f === void 0 ? {} : _f, _h = _g.status, status = _h === void 0 ? null : _h, _j = _g.statusText, statusText = _j === void 0 ? '-' : _j;
    if (stream)
        stream.write("\n" + moment().utc().format('DD MMM YYYY HH:mm:ss') + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + typeof data + "; " + status + "; " + statusText + "; " + code);
    logError({ axiosResponseError: axiosResponseError });
    throw axiosResponseError;
};
exports.baseAxiosResponseErrorInterceptor = baseAxiosResponseErrorInterceptor;
